Documentation
¶
Overview ¶
Package vearch contains an implementation of the VectorStore interface using vearch.
Index ¶
Constants ¶
const ( DefaultDBName = "ts_db" DefaultSpaceName = "ts_space" )
Variables ¶
var ErrInvalidOptions = errors.New("invalid options")
ErrInvalidOptions is returned when the options given are invalid.
Functions ¶
Types ¶
type Option ¶
type Option func(store *Store)
Option is a function that configures an Options.
func WithDBName ¶ added in v3.5.2
WithDbName returns an Option for setting the database name. Required.
func WithEmbedder ¶
func WithEmbedder(embedder embeddings.Embedder) Option
WithEmbedder is an option for setting the embedder to use. Must be set.
func WithSpaceName ¶
WithSpaceName returns an Option for setting the space name. Required.
Click to show internal directories.
Click to hide internal directories.